﻿using System;
using System.IO;
using System.Reflection;
using System.Threading;
using System.Threading.Tasks;
using PSHostsFile;

namespace GrowthLocalServer
{
	class Program
	{
		private static readonly CancellationTokenSource Cts = new CancellationTokenSource();


		static async Task Main(string[] args)
		{
			string htmlData;
			string jsonData;
			var assembly = Assembly.GetExecutingAssembly();

			using (Stream stream = assembly.GetManifestResourceStream("GrowthLocalServer.hello.html"))
			using (StreamReader reader = new StreamReader(stream))
			{
				htmlData = reader.ReadToEnd();
			}

			using (Stream stream = assembly.GetManifestResourceStream("GrowthLocalServer.hello.json"))
			using (StreamReader reader = new StreamReader(stream))
			{
				jsonData = reader.ReadToEnd();
			}

			try
			{
				Console.CancelKeyPress += OnCancelKeyPress;
				WebService.StartWebServer(htmlData, jsonData);
				Console.WriteLine("Listening");

				HostsFile.Set("growthrpg.com", "127.0.0.1");

				await Task.Delay(Timeout.Infinite, Cts.Token);
			}
			catch (Exception ex)
			{
				Console.WriteLine(ex.Message);
			}
			finally
			{
				WebService.StopWebServer();
				HostsFile.Remove("growthrpg.com");
			}
		}

		private static void OnCancelKeyPress(object sender, ConsoleCancelEventArgs e)
		{
			e.Cancel = true;
			Cts.Cancel();
		}
	}
}
