﻿using System;
using System.Net;
using System.Text;
using System.Threading.Tasks;

namespace GrowthLocalServer
{
	internal static class WebService
	{
		private const int Port = 80;
		private static readonly HttpListener Listener = new HttpListener { Prefixes = { $"http://growthrpg.com/" } };
		private static bool _keepGoing = true;
		private static Task _mainLoop;

		private static string HtmlData { get; set; }
		private static string JsonData { get; set; }

		public static void StartWebServer(string htmlData, string jsonData)
		{
			HtmlData = htmlData;
			JsonData = jsonData;

			if (_mainLoop != null && !_mainLoop.IsCompleted) return;
			_mainLoop = MainLoop();
		}

		public static void StopWebServer()
		{
			_keepGoing = false;
			lock (Listener)
			{
				Listener.Stop();
			}
			try
			{
				_mainLoop.Wait();
			}
			catch {}
		}

		private static async Task MainLoop()
		{
			Listener.Start();
			while (_keepGoing)
			{
				try
				{
					var context = await Listener.GetContextAsync();
					lock (Listener)
					{
						if (_keepGoing) ProcessRequest(context);
					}
				}
				catch (Exception e)
				{
					if (e is HttpListenerException) return;
				}
			}
		}

		private static void ProcessRequest(HttpListenerContext context)
		{
			using (var response = context.Response)
			{
				try
				{
					var handled = false;
					byte[] buffer;
					
					response.ContentType = "text/html";

					Console.WriteLine(context.Request.Url.AbsoluteUri);

					switch (context.Request.Url.AbsolutePath)
					{
						case "/Verification/get-token.php":
							buffer = Encoding.UTF8.GetBytes(HtmlData);
							response.ContentLength64 = buffer.Length;
							response.OutputStream.Write(buffer, 0, buffer.Length);
							handled = true;
							break;
						case "/Verification/process-patreon.php":
							buffer = Encoding.UTF8.GetBytes(JsonData);
							response.ContentLength64 = buffer.Length;
							response.OutputStream.Write(buffer, 0, buffer.Length);
							handled = true;
							break;
						case "/Verification/get-patreon-info.php":
							buffer = Encoding.UTF8.GetBytes(JsonData);
							response.ContentLength64 = buffer.Length;
							response.OutputStream.Write(buffer, 0, buffer.Length);
							handled = true;
							break;
					}
					if (!handled)
					{
						response.StatusCode = 404;
					}
				}
				catch (Exception e)
				{
					response.StatusCode = 500;
					response.ContentType = "application/json";
					var buffer = new byte[0];
					response.ContentLength64 = buffer.Length;
					response.OutputStream.Write(buffer, 0, buffer.Length);
				}
			}
		}

	}
}